@@ -68,8 +68,10 @@ sub StartTag
     ($tag) = $tag =~ /^<\s*((?:\w|\:|\-)*)/;
     my $att = { %_ };
 
+    $class->_use_macro ($tag, $att);
     $class->_on_error ($tag, $att);
     $class->_define ($tag, $att);
+    $class->_define_slot ($tag, $att);
     $class->_condition ($tag, $att);
     $class->_repeat ($tag, $att);
     $class->_is_xinclude ($tag) and $class->_xinclude ($tag, $att) and return;
@@ -97,7 +99,7 @@ sub StartTag
 		$command =~ s/^\$//;
 		$command =~ s/^\{//;
 		$command =~ s/\}$//;
-		$command = Petal::XML_Encode_Decode::encode_backslash_semicolon ($command);
+		$command = $class->_encode_backslash_semicolon ($command);
 		$command = "<?var name=\"$command\"?>";
 		$text =~ s/\Q$var\E/$command/g;
 	    }
@@ -150,7 +152,7 @@ sub StartTag
 	{
 	    if (defined $att->{"$petal:omit-tag"})
 	    {
-		my $expression = $att->{"$petal:omit-tag"};
+		my $expression = $att->{"$petal:omit-tag"} || 'string:1';
 		$Petal::Canonicalizer::XML::NodeStack[$#Petal::Canonicalizer::XML::NodeStack]->{'omit-tag'} = $expression;
 		push @Petal::Canonicalizer::XML::Result, (defined $att_str and $att_str) ?
 		    "<?if name=\"false:$expression\"?><$tag $att_str /><?end?>" :
@@ -232,7 +234,8 @@ sub EndTag
     
     my $repeat = $node->{repeat} || '0';
     my $condition = $node->{condition} || '0';
-    push @Petal::Canonicalizer::XML::Result, map { '<?end?>' } 1 .. ($repeat+$condition);
+    my $define_slot = $node->{define_slot} || '0';
+    push @Petal::Canonicalizer::XML::Result, map { '<?end?>' } 1 .. ($repeat+$condition+$define_slot);
     
     if (exists $node->{'on-error'})
     {
